PRO cloud_mask_plot

;*************************************************************************
; IDL routine
;
; cloud_mask_plot v 1.0
;
; This is the driver to plot Cloud Mask bit fields.
;  The code can be utilized to plot single or multiple granules,
;  whose bit fields have been extracted and written to an HDF file.
;
; Input: 
;		none
; 
; Output:
;    		none
;
; Required routines:
;    plotproduct
;
; Developer
;  v 1.0  03/20/2001
;           	Eric Moody moody@climate.gsfc.nasa.gov
;               Emergent IT
;               MODIS - Atmosphere Group
;
;*************************************************************************


;*************************************************************************
; Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.  If plotting more than 
;  one granule, increase the NumTimes to reflect the number of granules,
;  and add to the TimeArr time array.
;*************************************************************************
;Define the text strings to use:
Year = '2000'
Day  = '336'

;Define the times to plot:
NumTimes   = 1
TimeArr    = StrArr(NumTimes)
TimeArr[0] = '0845'


;*************************************************************************
; Define the files that contain the bit fields.
;  Either single or multiple granules can be specified, but in either case,
;  they must be placed into the filenames array.  Please include paths.
;   	Ex.
;          filenames = ['./inputs/CloudMaskTests.2000.110.0850.hdf']
;	   filenames = ['ClMskTst.2000.110.0850.hdf',ClMskTst.2000.110.0855.hdf']
;*************************************************************************
;Define the path where the CloudMask HDF files reside:
QAPath = '../CloudMaskExtracter/output/'

;Create the filenames array:
filenames   = StrArr(NumTimes)

;Fill in the filenames array:
for icnt = 0, NumTimes-1 do begin
    filenames[icnt] = QAPath+'CloudMaskTests.'+ $
                      Year+'.'+Day+'.'+TimeArr[icnt]+'.hdf'
endfor


;*************************************************************************
; Define the text string that will appear after the sds name.
;  Ex. The products will be named sdsname.textstring.ps
;      So one use would be to have the year.day.hourminute
;      outtextstring = '2000.110.0855'
;*************************************************************************
outtextstring = '.'+Year+'.'+Day+'.'
if (NumTimes eq 1) then begin
   outtextstring = outtextstring + TimeArr[0]
endif else begin
   for icnt = 0, NumTimes-2 do begin
       outtextstring = outtextstring + TimeArr[icnt] + '_'
   endfor
   outtextstring = outtextstring + TimeArr[NumTimes-1]
endelse


;*************************************************************************
; Define the text string that will appear in the plot title, after the sds name.
;  Ex. The Title will be sdsname, textstring
;      So one use would be to have the year.day.hourminute
;      plottextstring = 'Year 2000, Julian Day 110, 08:55'
;*************************************************************************
plottextstring = 'Day '+Day+', '+Year+' '
if (NumTimes eq 1) then begin
   plottextstring = plottextstring + ', Time ' + TimeArr[0] + '.'
endif else begin
   plottextstring = plottextstring + ', Times '
   for icnt = 0, NumTimes-2 do begin
       plottextstring = plottextstring + TimeArr[icnt] + ', '
   endfor
   plottextstring = plottextstring + TimeArr[NumTimes-1] + '.'
endelse
plottextstring = plottextstring + ' UTC'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   of the granule(s) to plot.  The format is as follows:
;   	limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please comment this 
;   definition out.
;*************************************************************************
;limits=[-10.,110.,-40.,160.]; Australia



;*************************************************************************
; Define which SDS you would like to produce a plot of. 
; 1 means yes, 0 means no.
;  Note that only MOD35 has the last three flags.
;*************************************************************************
;Define the number of SDSs:
numSDS = 9
plot_sds    = intarr(numSDS)
plot_sds[0] = 1  ; Determined_Flag
plot_sds[1] = 1  ; Percent_Cloudy
plot_sds[2] = 1  ; Day_Night_Flag
plot_sds[3] = 1  ; Sun_Glint_Flag
plot_sds[4] = 1  ; Snow_Ice_Flag
plot_sds[5] = 1  ; Surface_Type
plot_sds[6] = 1  ; Heavy_Aerosol
plot_sds[7] = 1  ; Thin_Cirrus_Detect_Vis
plot_sds[8] = 1  ; Shadow_Found




;*************************************************************************
;*************************************************************************
; End of Definition section, Edit the lines below at your own risk.
;*************************************************************************
;*************************************************************************



;*************************************************************************
;Define the sds_name to be plotted.
;  For the cloud mask, the options are:
;	Determined_Flag, Percent_Cloudy, Day_Night_Flag, 
;	Sun_Glint_Flag, Snow_Ice_Flag, Surface_Type
;  For the L2 QA, the options are:
;*************************************************************************
sds_name_arr = strarr(numSDS)
sds_name_arr[0]= 'Determined_Flag'
sds_name_arr[1] = 'Percent_Cloudy'
sds_name_arr[2] = 'Day_Night_Flag'
sds_name_arr[3] = 'Sun_Glint_Flag'
sds_name_arr[4] = 'Snow_Ice_Flag'
sds_name_arr[5] = 'Surface_Type'
sds_name_arr[6] = 'Heavy_Aerosol'
sds_name_arr[7] = 'Thin_Cirrus_Detect_Vis'
sds_name_arr[8] = 'Shadow_Found'


;*************************************************************************
;Define the red, green, blue colors to use for the color bar.
;  Ex.  If the parameter is a yes, no, define the yes as green and 
;       the no as red, as follows:
;       values -> 0 = no, 1 = yes
;       rplot = [255,  0]
;       gplot = [  0,255]
;       bplot = [  0,  0] 
;*************************************************************************
;Initialize the arrays:
rplot_arr = intarr(4,numSDS)
gplot_arr = intarr(4,numSDS)
bplot_arr = intarr(4,numSDS)
;Define the colors for Determined Flag:
; 0 = Undetermined (Red), 1 = Determined (Green)
rplot_arr[*,0] = [255,  0,  0,  0]
gplot_arr[*,0] = [  0,255,  0,  0]
bplot_arr[*,0] = [  0,  0,  0,  0]
;Define the colors for Percent Cloudy:
; 0 = Cloudy (White), 1 = Pr Cloudy (Green), 2 = Pr Clear (Blue), 3 = Conf. Clear (Grey) 
rplot_arr[*,1] = [255,  0,  0, 50]
gplot_arr[*,1] = [255,255,  0, 50]
bplot_arr[*,1] = [255,  0,255, 50]
;Define the colors for Day/Night Flag:
; 0 = Night (Dark Blue), 1 = Day (Yellow)
rplot_arr[*,2] = [100,239,  0,  0]
gplot_arr[*,2] = [100,251,  0,  0]
bplot_arr[*,2] = [255,  0,  0,  0]
;Define the colors for SunGlint Flag:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,3] = [235,150,  0,  0]
gplot_arr[*,3] = [235,150,  0,  0]
bplot_arr[*,3] = [235,150,  0,  0]
;Define the colors for Snow/Ice Flag:
; 0 = Yes (White), 1 = No (blue)
rplot_arr[*,4] = [245, 50,  0,  0]
gplot_arr[*,4] = [245, 50,  0,  0]
bplot_arr[*,4] = [245,255,  0,  0]
;Define the colors for the Land/Water Flag:
; 0 = Water (blue), 1 = Costal (red), 2 = Desert (Yellow), 3 = Land (Green)
rplot_arr[*,5] = [ 71,255,239,  0]
gplot_arr[*,5] = [158,  0,251,255]
bplot_arr[*,5] = [255,  0,  0,  0]
;Define the colors for Heavy Aerosol:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,6] = [255,100,  0,  0]
gplot_arr[*,6] = [255,100,  0,  0]
bplot_arr[*,6] = [255,100,  0,  0]
;Define the colors for Thin Cirrus Detected, visable:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,7] = [255,100,  0,  0]
gplot_arr[*,7] = [255,100,  0,  0]
bplot_arr[*,7] = [255,100,  0,  0]
;Define the colors for Shadow Found:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,8] = [255,100,  0,  0]
gplot_arr[*,8] = [255,100,  0,  0]
bplot_arr[*,8] = [255,100,  0,  0]


;*************************************************************************
; Loop over all the sds and plot if sds_plot = 1:
;*************************************************************************
FOR icnt = 0, numSDS-1 DO BEGIN


   ;*************************************************************************
   ;Load the appropriate sds_name and color scheme:
   ;*************************************************************************
   sds_name = sds_name_arr[icnt]
   rplot    = rplot_arr [*,icnt]
   gplot    = gplot_arr [*,icnt]
   bplot    = bplot_arr [*,icnt]


   ;*************************************************************************
   ; Provide the name and path of the output image file, for example:
   ;	OutFileName = 'GlobalEcosystemMap.3600X1800.ps'
   ;*************************************************************************
   OutFileName = './output/CloudMask/'+sds_name+outtextstring+'.ps'
 
   ;*************************************************************************
   ;Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = sds_name+plottextstring

   ;*************************************************************************
   ;Call the program, bearing in mind that only the postscript output is 
   ; available.  The basic call is as follows:
   ; 	plotproduct, filenames,sds_name,OutFileName,rplot,gplot,rplot,/ps
   ; In addition, if you define limits, add this on:
   ;	plotproduct, filenames,sds_name,OutFileName,rplot,gplot,rplot,limits, /ps
   ; There are several key word options that can be added to the call
   ;	/notation  - adds the title string to the output
   ;	/cylindrical - plots in cylindrical coordinates
   ;	/world - neccessary for plotting the world map, in Robinson projection.
   ; Here is an example call:
   ;  plotproduct, filenames, sds_name, OutFileName,rplot,gplot,rplot,titlestring,/ps
   ;*************************************************************************
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (plot_sds[icnt] eq 1) THEN BEGIN
      print, 'Plotting ',sds_name
      plotproduct, filenames, sds_name, OutFileName, $
                   rplot, gplot, bplot, titlestring, /ps, /notation
   ENDIF ELSE BEGIN
      print, 'Skipping ',sds_name
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
ENDFOR

;*************************************************************************
;End the script:
;*************************************************************************

END
