function make_minimap,centrallat,centrallong,mapsize
; IDL routine
;
;  make_minimap.pro v 0.5
;
; routine to take a central lat and long, create a map of the earth
; using the z-buffer, noting the central lat/long on the map in red
; and returning the resultant image back as a small (say 250x250) pixel
; byte array suitable for image work
;
; usage is: minimapimage = minimap,somelat,somelong,mapsize
; where somelat,somelong is a lat long pair and mapsize is
; the size (in pixels) of the square image returned;
;
; v 0.5 notes:
;
; Keywords:
;
; Input: 
;    centrallat  float    central latitude
;    centrallong float    central longitude
;    mapsize     integer  size of square image (in pixels)
;
; Output:
;    minimapimage byte array rgb image of map with a red dot at the center to note a point of interest
;
; Required routines:
;    none
;
; Developer
;  v .5         Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group
restore,'mycolors.sav'
r = congrid(r,!d.n_colors)
g = congrid(g,!d.n_colors)
b = congrid(b,!d.n_colors)
tvlct,r,g,b

minimapimage=bytarr(mapsize,mapsize,3)
set_plot,'z'
device,set_resolution=[mapsize,mapsize]
dotsize=16
;Make a vector of 16 points, A[i] = 3pi/dotsize
A = FINDGEN(dotsize+1) * (!PI*2/dotsize)
;Define the symbol to be a unit circle with dotsize points.
;Set the filled flag:
USERSYM, 2*COS(A), 2*SIN(A), /FILL
latitude=fltarr(1)
longitude=fltarr(1)
latitude(0)=centrallat
longitude(0)=centrallong

map_set,centrallat,centrallong,/stereo,/grid,e_continents={fill:1},/isotropic,/horizon,color=1

oplot,longitude,latitude,psym=8,color=255

minimapimage=tvrd()

return,minimapimage
end
