pro plotproduct,filenames,sds_name,outputname,rplot,gplot,bplot, $
                titlestring,limits,                              $
                cylindrical=cylindrical,ps=ps,jpeg=jpeg,         $
	        tiff=tiff,notation=notation,world=world


;For debugging purposes, set productname to dummy value
productname = 'bit'

;If notation is not desired, reset the titlestring:
if not keyword_set(notation) then titlestring=''

;Determine the number of files to process:
numberoffiles=size(filenames)
numberoffiles=numberoffiles[1]

;Determine the geolocation limits for the map:
if not keyword_set(world) then begin
  if n_elements(limits) eq 4 then begin
     latlonglimits=limits
     center=fltarr(2)
     center[0]=(limits[0]+limits[2])/2.
     center[1]=(limits[1]+limits[3])/2.
  endif else begin
     optimumscale,filenames,numberoffiles,scalesetting,center,latlonglimits
  endelse

  print,'Lat/long limits are :'
  print,latlonglimits[0],latlonglimits[2],'   degrees latitude'
  print,latlonglimits[1],latlonglimits[3],'   degrees longitude'
  mapsize=300
  worldmap=make_minimap(center[0],center[1],mapsize)
  worldmap=worldmap[*,*,0]
endif

;Set up the output display.
if  keyword_set(world) then begin
    if keyword_set(ps) then setup_display,filenames,titlestring,outputname,/world,/ps
    if keyword_set(jpeg) then setup_display,filenames,titlestring,outputname,/world,/jpeg
endif else begin
    if keyword_set(ps) then setup_display, $
           filenames,titlestring,outputname,scalesettings,latlonglimits,center,/ps
    if keyword_set(jpeg) or keyword_set(tiff) and not keyword_set(cylindrical) then $
       setup_display,filenames,titlestring,outputname,scalesettings,latlonglimits,center,/jpeg
    if keyword_set(jpeg) or keyword_set(tiff) and keyword_set(cylindrical) then $
       setup_display,filenames,titlestring,outputname,scalesettings,latlonglimits, $
                     center,/jpeg,/cylindrical
endelse


;Determine the valid range for this SDS and read in the descriptors:
get_annotes, filenames[0],sds_name,descriptions,valid_values


;Begin to add the data to the image:
imageflag=0
faillist=intarr(numberoffiles)

for fileloop=0,numberoffiles-1 do begin
 print,filenames[fileloop],' is being acquired. Please stand by'
 if keyword_set(world) then  addproduct,filenames[fileloop],addimage,sds_name, $
					xparameter,productname,fail,/quick
 if not keyword_set(world) then addproduct,filenames[fileloop],addimage,       $
					sds_name,xparameter,productname,fail

 if fail eq 0 then imageflag=imageflag+1

 if fail  eq 1 then faillist[fileloop]=1

 if  imageflag eq 1 then finalimage=addimage

 if  imageflag gt 1 and fail eq 0 then begin
   unsetpixels=where(finalimage eq 0 ,unsetcount)
   goodaddpixels=where(addimage gt 0,goodaddcount)
   if goodaddcount gt 0 then finalimage(goodaddpixels) = addimage(goodaddpixels)
   addimage=0
 endif
endfor


;sds_name=data_sds_name
;get_modis_data,filename,sds_name,latitude,longitude,data,fail,datarange

totalfail=0
if total(faillist) lt numberoffiles then begin
  totalfail=0
endif else begin
  totalfail=1
endelse

if totalfail eq 0 then begin
  ;finalrange=imclip(finalimage,percent=3)
  if keyword_set(notation) then begin
    if keyword_set(ps) then output_productmap,finalimage,finalrange,xparameter,     $
					      outputname,descriptions,valid_values, $
					      rplot,gplot,bplot,                    $
					      /psdisplay,/notation
    if keyword_set(jpeg) then  output_productmap,finalimage,finalrange,xparameter, $
						 outputname,/jpeg,/notation
    if keyword_set(tiff) then  output_productmap,finalimage,finalrange,xparameter, $
						 outputname,/tiff,/notation
  endif else begin
    if keyword_set(ps) then output_productmap,finalimage,finalrange,xparameter, $
					      outputname,descriptions,          $
					      rplot,gplot,bplot,                $
					      valid_values,/psdisplay
    if keyword_set(jpeg) then  output_productmap,finalimage,finalrange, $
						 xparameter,outputname,/jpeg
    if keyword_set(tiff) then  output_productmap,finalimage,finalrange, $
						 xparameter,outputname,/tiff
  endelse
endif


end

