PRO cloudmaskextracter, inputyear, inputday, inputtime, $
                        MODFlag, MODFileName,           $
                        ClMaskHDFFileName, ClMaskSDSName

; IDL routine
;
; cloudmaskextracter.pro v 1.0
;
; cloudMaskExtracter.pro will retreive individual cloud mask test results
;   from the full byte cloud mask, from the input file.  The test results
;   are written into an output HDF file, as seperate byte SDSs. 
;   This code can serve as an example/template for extracting bit flags
;   from byte arrays.
;
;
; Input: 
;    inputday		String	   : Julian Day
;    inputyear		String     : Year
;    inputtime		String	   : Time as HHMM (H=hour, M=minute)
;    MODFlag		Integer	   : MOD to be examined.
;    MODFileName	String	   : The path and name of the MOD granule.
;    ClMaskHDFFileName	String	   : The path and name for the output HDF file.
;    ClMaskSDSName      String	   : The name of the Cloud Mask SDS.
; 
; Output:
;    		none
;
; Required routines:
;    ReadSDS
;    clm_bitextracter
;    outputcloudmaskbits
;
; Developer
;  v 1.0    03/20/2001
;   	Eric Moody moody@climate.gsfc.nasa.gov
;       Emergent IT
;       MODIS - Atmosphere Group
;


;*************************************************************************
;Read in the Lat Lons:
;*************************************************************************
MODFileID = HDF_SD_START(MODFileName,/READ)
LatArray = ReadSDS(MODFileID,'Latitude',/scaleNo,/offsetNo)
LonArray = ReadSDS(MODFileID,'Longitude',/scaleNo,/offsetNo)
HDF_SD_END, MODFileID


;*************************************************************************
;Extract the individual cloud mask test results:
;*************************************************************************
CloudMaskTests = clm_bitextracter(MODFlag, MODFileName, ClMaskSDSName)


;*************************************************************************
;Output the Cloud Mask Tests and Lat/Lon to the HDF file:
;*************************************************************************
outputcloudmaskbits, LatArray, LonArray, MODFlag,       $
                     CloudMaskTests, ClMaskHDFFileName, $
                     inputDay, inputYear, inputTime



END